Module: Aws::DocDBElastic

Defined in:
lib/aws-sdk-docdbelastic/endpoint_parameters.rb,
sig/client.rbs,
sig/errors.rbs,
sig/waiters.rbs,
sig/resource.rbs,
lib/aws-sdk-docdbelastic/plugins/endpoints.rb,
lib/aws-sdk-docdbelastic/endpoint_provider.rb,
lib/aws-sdk-docdbelastic/client_api.rb,
lib/aws-sdk-docdbelastic/endpoints.rb,
lib/aws-sdk-docdbelastic/resource.rb,
lib/aws-sdk-docdbelastic/errors.rb,
lib/aws-sdk-docdbelastic/client.rb,
lib/aws-sdk-docdbelastic/types.rb,
lib/aws-sdk-docdbelastic.rb

Overview

This module provides support for Amazon DocumentDB Elastic Clusters. This module is available in the aws-sdk-docdbelastic gem.

Client

The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.

doc_db_elastic = Aws::DocDBElastic::Client.new
resp = doc_db_elastic.apply_pending_maintenance_action(params)

See Client for more information.

Errors

Errors returned from Amazon DocumentDB Elastic Clusters are defined in the Errors module and all extend Errors::ServiceError.

begin
  # do stuff
rescue Aws::DocDBElastic::Errors::ServiceError
  # rescues all Amazon DocumentDB Elastic Clusters API errors
end

See Errors for more information.

Defined Under Namespace

Modules: ClientApi, Endpoints, Errors, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource

service collapse

GEM_VERSION =
'1.48.0'