Class: Aws::DocDBElastic::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DocDBElastic::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-docdbelastic/client.rb,
sig/client.rbs
Overview
An API client for DocDBElastic. To construct a client, you need to configure a :region and :credentials.
client = Aws::DocDBElastic::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _ApplyPendingMaintenanceActionResponseSuccess, _CopyClusterSnapshotResponseSuccess, _CreateClusterResponseSuccess, _CreateClusterSnapshotResponseSuccess, _DeleteClusterResponseSuccess, _DeleteClusterSnapshotResponseSuccess, _GetClusterResponseSuccess, _GetClusterSnapshotResponseSuccess, _GetPendingMaintenanceActionResponseSuccess, _ListClusterSnapshotsResponseSuccess, _ListClustersResponseSuccess, _ListPendingMaintenanceActionsResponseSuccess, _ListTagsForResourceResponseSuccess, _RestoreClusterFromSnapshotResponseSuccess, _StartClusterResponseSuccess, _StopClusterResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateClusterResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#apply_pending_maintenance_action(params = {}) ⇒ Types::ApplyPendingMaintenanceActionOutput
The type of pending maintenance action to be applied to the resource.
-
#copy_cluster_snapshot(params = {}) ⇒ Types::CopyClusterSnapshotOutput
Copies a snapshot of an elastic cluster.
-
#create_cluster(params = {}) ⇒ Types::CreateClusterOutput
Creates a new Amazon DocumentDB elastic cluster and returns its cluster structure.
-
#create_cluster_snapshot(params = {}) ⇒ Types::CreateClusterSnapshotOutput
Creates a snapshot of an elastic cluster.
-
#delete_cluster(params = {}) ⇒ Types::DeleteClusterOutput
Delete an elastic cluster.
-
#delete_cluster_snapshot(params = {}) ⇒ Types::DeleteClusterSnapshotOutput
Delete an elastic cluster snapshot.
-
#get_cluster(params = {}) ⇒ Types::GetClusterOutput
Returns information about a specific elastic cluster.
-
#get_cluster_snapshot(params = {}) ⇒ Types::GetClusterSnapshotOutput
Returns information about a specific elastic cluster snapshot.
-
#get_pending_maintenance_action(params = {}) ⇒ Types::GetPendingMaintenanceActionOutput
Retrieves all maintenance actions that are pending.
-
#list_cluster_snapshots(params = {}) ⇒ Types::ListClusterSnapshotsOutput
Returns information about snapshots for a specified elastic cluster.
-
#list_clusters(params = {}) ⇒ Types::ListClustersOutput
Returns information about provisioned Amazon DocumentDB elastic clusters.
-
#list_pending_maintenance_actions(params = {}) ⇒ Types::ListPendingMaintenanceActionsOutput
Retrieves a list of all maintenance actions that are pending.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags on a elastic cluster resource.
-
#restore_cluster_from_snapshot(params = {}) ⇒ Types::RestoreClusterFromSnapshotOutput
Restores an elastic cluster from a snapshot.
-
#start_cluster(params = {}) ⇒ Types::StartClusterOutput
Restarts the stopped elastic cluster that is specified by
clusterARN. -
#stop_cluster(params = {}) ⇒ Types::StopClusterOutput
Stops the running elastic cluster that is specified by
clusterArn. -
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to an elastic cluster resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from an elastic cluster resource.
-
#update_cluster(params = {}) ⇒ Types::UpdateClusterOutput
Modifies an elastic cluster.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1652 1653 1654 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1652 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1655 1656 1657 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1655 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#apply_pending_maintenance_action(params = {}) ⇒ Types::ApplyPendingMaintenanceActionOutput
The type of pending maintenance action to be applied to the resource.
86 |
# File 'sig/client.rbs', line 86
def apply_pending_maintenance_action: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1625 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DocDBElastic') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-docdbelastic' context[:gem_version] = '1.48.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_cluster_snapshot(params = {}) ⇒ Types::CopyClusterSnapshotOutput
Copies a snapshot of an elastic cluster.
99 |
# File 'sig/client.rbs', line 99
def copy_cluster_snapshot: (
|
#create_cluster(params = {}) ⇒ Types::CreateClusterOutput
Creates a new Amazon DocumentDB elastic cluster and returns its cluster structure.
113 |
# File 'sig/client.rbs', line 113
def create_cluster: (
|
#create_cluster_snapshot(params = {}) ⇒ Types::CreateClusterSnapshotOutput
Creates a snapshot of an elastic cluster.
137 |
# File 'sig/client.rbs', line 137
def create_cluster_snapshot: (
|
#delete_cluster(params = {}) ⇒ Types::DeleteClusterOutput
Delete an elastic cluster.
149 |
# File 'sig/client.rbs', line 149
def delete_cluster: (
|
#delete_cluster_snapshot(params = {}) ⇒ Types::DeleteClusterSnapshotOutput
Delete an elastic cluster snapshot.
159 |
# File 'sig/client.rbs', line 159
def delete_cluster_snapshot: (
|
#get_cluster(params = {}) ⇒ Types::GetClusterOutput
Returns information about a specific elastic cluster.
169 |
# File 'sig/client.rbs', line 169
def get_cluster: (
|
#get_cluster_snapshot(params = {}) ⇒ Types::GetClusterSnapshotOutput
Returns information about a specific elastic cluster snapshot
179 |
# File 'sig/client.rbs', line 179
def get_cluster_snapshot: (
|
#get_pending_maintenance_action(params = {}) ⇒ Types::GetPendingMaintenanceActionOutput
Retrieves all maintenance actions that are pending.
189 |
# File 'sig/client.rbs', line 189
def get_pending_maintenance_action: (
|
#list_cluster_snapshots(params = {}) ⇒ Types::ListClusterSnapshotsOutput
Returns information about snapshots for a specified elastic cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
200 |
# File 'sig/client.rbs', line 200
def list_cluster_snapshots: (
|
#list_clusters(params = {}) ⇒ Types::ListClustersOutput
Returns information about provisioned Amazon DocumentDB elastic clusters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
214 |
# File 'sig/client.rbs', line 214
def list_clusters: (
|
#list_pending_maintenance_actions(params = {}) ⇒ Types::ListPendingMaintenanceActionsOutput
Retrieves a list of all maintenance actions that are pending.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
226 |
# File 'sig/client.rbs', line 226
def list_pending_maintenance_actions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags on a elastic cluster resource
237 |
# File 'sig/client.rbs', line 237
def list_tags_for_resource: (
|
#restore_cluster_from_snapshot(params = {}) ⇒ Types::RestoreClusterFromSnapshotOutput
Restores an elastic cluster from a snapshot.
247 |
# File 'sig/client.rbs', line 247
def restore_cluster_from_snapshot: (
|
#start_cluster(params = {}) ⇒ Types::StartClusterOutput
Restarts the stopped elastic cluster that is specified by
clusterARN.
264 |
# File 'sig/client.rbs', line 264
def start_cluster: (
|
#stop_cluster(params = {}) ⇒ Types::StopClusterOutput
Stops the running elastic cluster that is specified by clusterArn.
The elastic cluster must be in the available state.
274 |
# File 'sig/client.rbs', line 274
def stop_cluster: (
|
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to an elastic cluster resource
283 |
# File 'sig/client.rbs', line 283
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from an elastic cluster resource
293 |
# File 'sig/client.rbs', line 293
def untag_resource: (
|
#update_cluster(params = {}) ⇒ Types::UpdateClusterOutput
Modifies an elastic cluster. This includes updating admin-username/password, upgrading the API version, and setting up a backup window and maintenance window
304 |
# File 'sig/client.rbs', line 304
def update_cluster: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1645 1646 1647 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1645 def waiter_names [] end |