Class: Aws::DocDBElastic::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DocDBElastic::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-docdbelastic/client.rb
Overview
An API client for DocDBElastic. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DocDBElastic::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#apply_pending_maintenance_action(params = {}) ⇒ Types::ApplyPendingMaintenanceActionOutput
The type of pending maintenance action to be applied to the resource.
-
#copy_cluster_snapshot(params = {}) ⇒ Types::CopyClusterSnapshotOutput
Copies a snapshot of an elastic cluster.
-
#create_cluster(params = {}) ⇒ Types::CreateClusterOutput
Creates a new Amazon DocumentDB elastic cluster and returns its cluster structure.
-
#create_cluster_snapshot(params = {}) ⇒ Types::CreateClusterSnapshotOutput
Creates a snapshot of an elastic cluster.
-
#delete_cluster(params = {}) ⇒ Types::DeleteClusterOutput
Delete an elastic cluster.
-
#delete_cluster_snapshot(params = {}) ⇒ Types::DeleteClusterSnapshotOutput
Delete an elastic cluster snapshot.
-
#get_cluster(params = {}) ⇒ Types::GetClusterOutput
Returns information about a specific elastic cluster.
-
#get_cluster_snapshot(params = {}) ⇒ Types::GetClusterSnapshotOutput
Returns information about a specific elastic cluster snapshot.
-
#get_pending_maintenance_action(params = {}) ⇒ Types::GetPendingMaintenanceActionOutput
Retrieves all maintenance actions that are pending.
-
#list_cluster_snapshots(params = {}) ⇒ Types::ListClusterSnapshotsOutput
Returns information about snapshots for a specified elastic cluster.
-
#list_clusters(params = {}) ⇒ Types::ListClustersOutput
Returns information about provisioned Amazon DocumentDB elastic clusters.
-
#list_pending_maintenance_actions(params = {}) ⇒ Types::ListPendingMaintenanceActionsOutput
Retrieves a list of all maintenance actions that are pending.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags on a elastic cluster resource.
-
#restore_cluster_from_snapshot(params = {}) ⇒ Types::RestoreClusterFromSnapshotOutput
Restores an elastic cluster from a snapshot.
-
#start_cluster(params = {}) ⇒ Types::StartClusterOutput
Restarts the stopped elastic cluster that is specified by ‘clusterARN`.
-
#stop_cluster(params = {}) ⇒ Types::StopClusterOutput
Stops the running elastic cluster that is specified by ‘clusterArn`.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to an elastic cluster resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from an elastic cluster resource.
-
#update_cluster(params = {}) ⇒ Types::UpdateClusterOutput
Modifies an elastic cluster.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1652 1653 1654 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1652 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1655 1656 1657 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1655 def errors_module Errors end |
Instance Method Details
#apply_pending_maintenance_action(params = {}) ⇒ Types::ApplyPendingMaintenanceActionOutput
The type of pending maintenance action to be applied to the resource.
534 535 536 537 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 534 def apply_pending_maintenance_action(params = {}, = {}) req = build_request(:apply_pending_maintenance_action, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1625 1626 1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1625 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DocDBElastic') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-docdbelastic' context[:gem_version] = '1.46.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_cluster_snapshot(params = {}) ⇒ Types::CopyClusterSnapshotOutput
Copies a snapshot of an elastic cluster.
626 627 628 629 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 626 def copy_cluster_snapshot(params = {}, = {}) req = build_request(:copy_cluster_snapshot, params) req.send_request() end |
#create_cluster(params = {}) ⇒ Types::CreateClusterOutput
Creates a new Amazon DocumentDB elastic cluster and returns its cluster structure.
793 794 795 796 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 793 def create_cluster(params = {}, = {}) req = build_request(:create_cluster, params) req.send_request() end |
#create_cluster_snapshot(params = {}) ⇒ Types::CreateClusterSnapshotOutput
Creates a snapshot of an elastic cluster.
844 845 846 847 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 844 def create_cluster_snapshot(params = {}, = {}) req = build_request(:create_cluster_snapshot, params) req.send_request() end |
#delete_cluster(params = {}) ⇒ Types::DeleteClusterOutput
Delete an elastic cluster.
893 894 895 896 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 893 def delete_cluster(params = {}, = {}) req = build_request(:delete_cluster, params) req.send_request() end |
#delete_cluster_snapshot(params = {}) ⇒ Types::DeleteClusterSnapshotOutput
Delete an elastic cluster snapshot.
934 935 936 937 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 934 def delete_cluster_snapshot(params = {}, = {}) req = build_request(:delete_cluster_snapshot, params) req.send_request() end |
#get_cluster(params = {}) ⇒ Types::GetClusterOutput
Returns information about a specific elastic cluster.
983 984 985 986 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 983 def get_cluster(params = {}, = {}) req = build_request(:get_cluster, params) req.send_request() end |
#get_cluster_snapshot(params = {}) ⇒ Types::GetClusterSnapshotOutput
Returns information about a specific elastic cluster snapshot
1023 1024 1025 1026 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1023 def get_cluster_snapshot(params = {}, = {}) req = build_request(:get_cluster_snapshot, params) req.send_request() end |
#get_pending_maintenance_action(params = {}) ⇒ Types::GetPendingMaintenanceActionOutput
Retrieves all maintenance actions that are pending.
1059 1060 1061 1062 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1059 def get_pending_maintenance_action(params = {}, = {}) req = build_request(:get_pending_maintenance_action, params) req.send_request() end |
#list_cluster_snapshots(params = {}) ⇒ Types::ListClusterSnapshotsOutput
Returns information about snapshots for a specified elastic cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1121 1122 1123 1124 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1121 def list_cluster_snapshots(params = {}, = {}) req = build_request(:list_cluster_snapshots, params) req.send_request() end |
#list_clusters(params = {}) ⇒ Types::ListClustersOutput
Returns information about provisioned Amazon DocumentDB elastic clusters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1167 1168 1169 1170 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1167 def list_clusters(params = {}, = {}) req = build_request(:list_clusters, params) req.send_request() end |
#list_pending_maintenance_actions(params = {}) ⇒ Types::ListPendingMaintenanceActionsOutput
Retrieves a list of all maintenance actions that are pending.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1216 1217 1218 1219 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1216 def list_pending_maintenance_actions(params = {}, = {}) req = build_request(:list_pending_maintenance_actions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags on a elastic cluster resource
1245 1246 1247 1248 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1245 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#restore_cluster_from_snapshot(params = {}) ⇒ Types::RestoreClusterFromSnapshotOutput
Restores an elastic cluster from a snapshot.
1340 1341 1342 1343 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1340 def restore_cluster_from_snapshot(params = {}, = {}) req = build_request(:restore_cluster_from_snapshot, params) req.send_request() end |
#start_cluster(params = {}) ⇒ Types::StartClusterOutput
Restarts the stopped elastic cluster that is specified by ‘clusterARN`.
1390 1391 1392 1393 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1390 def start_cluster(params = {}, = {}) req = build_request(:start_cluster, params) req.send_request() end |
#stop_cluster(params = {}) ⇒ Types::StopClusterOutput
Stops the running elastic cluster that is specified by ‘clusterArn`. The elastic cluster must be in the available state.
1440 1441 1442 1443 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1440 def stop_cluster(params = {}, = {}) req = build_request(:stop_cluster, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to an elastic cluster resource
1468 1469 1470 1471 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1468 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from an elastic cluster resource
1494 1495 1496 1497 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1494 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_cluster(params = {}) ⇒ Types::UpdateClusterOutput
Modifies an elastic cluster. This includes updating admin-username/password, upgrading the API version, and setting up a backup window and maintenance window
1616 1617 1618 1619 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1616 def update_cluster(params = {}, = {}) req = build_request(:update_cluster, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1645 1646 1647 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1645 def waiter_names [] end |