Class: Aws::DocDBElastic::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DocDBElastic::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-docdbelastic/client.rb
Overview
An API client for DocDBElastic. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::DocDBElastic::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#apply_pending_maintenance_action(params = {}) ⇒ Types::ApplyPendingMaintenanceActionOutput
The type of pending maintenance action to be applied to the resource.
-
#copy_cluster_snapshot(params = {}) ⇒ Types::CopyClusterSnapshotOutput
Copies a snapshot of an elastic cluster.
-
#create_cluster(params = {}) ⇒ Types::CreateClusterOutput
Creates a new Amazon DocumentDB elastic cluster and returns its cluster structure.
-
#create_cluster_snapshot(params = {}) ⇒ Types::CreateClusterSnapshotOutput
Creates a snapshot of an elastic cluster.
-
#delete_cluster(params = {}) ⇒ Types::DeleteClusterOutput
Delete an elastic cluster.
-
#delete_cluster_snapshot(params = {}) ⇒ Types::DeleteClusterSnapshotOutput
Delete an elastic cluster snapshot.
-
#get_cluster(params = {}) ⇒ Types::GetClusterOutput
Returns information about a specific elastic cluster.
-
#get_cluster_snapshot(params = {}) ⇒ Types::GetClusterSnapshotOutput
Returns information about a specific elastic cluster snapshot.
-
#get_pending_maintenance_action(params = {}) ⇒ Types::GetPendingMaintenanceActionOutput
Retrieves all maintenance actions that are pending.
-
#list_cluster_snapshots(params = {}) ⇒ Types::ListClusterSnapshotsOutput
Returns information about snapshots for a specified elastic cluster.
-
#list_clusters(params = {}) ⇒ Types::ListClustersOutput
Returns information about provisioned Amazon DocumentDB elastic clusters.
-
#list_pending_maintenance_actions(params = {}) ⇒ Types::ListPendingMaintenanceActionsOutput
Retrieves a list of all maintenance actions that are pending.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags on a elastic cluster resource.
-
#restore_cluster_from_snapshot(params = {}) ⇒ Types::RestoreClusterFromSnapshotOutput
Restores an elastic cluster from a snapshot.
-
#start_cluster(params = {}) ⇒ Types::StartClusterOutput
Restarts the stopped elastic cluster that is specified by ‘clusterARN`.
-
#stop_cluster(params = {}) ⇒ Types::StopClusterOutput
Stops the running elastic cluster that is specified by ‘clusterArn`.
-
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to an elastic cluster resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from an elastic cluster resource.
-
#update_cluster(params = {}) ⇒ Types::UpdateClusterOutput
Modifies an elastic cluster.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1654 1655 1656 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1654 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1657 1658 1659 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1657 def errors_module Errors end |
Instance Method Details
#apply_pending_maintenance_action(params = {}) ⇒ Types::ApplyPendingMaintenanceActionOutput
The type of pending maintenance action to be applied to the resource.
536 537 538 539 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 536 def apply_pending_maintenance_action(params = {}, = {}) req = build_request(:apply_pending_maintenance_action, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1627 1628 1629 1630 1631 1632 1633 1634 1635 1636 1637 1638 1639 1640 1641 1642 1643 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1627 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DocDBElastic') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-docdbelastic' context[:gem_version] = '1.45.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_cluster_snapshot(params = {}) ⇒ Types::CopyClusterSnapshotOutput
Copies a snapshot of an elastic cluster.
628 629 630 631 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 628 def copy_cluster_snapshot(params = {}, = {}) req = build_request(:copy_cluster_snapshot, params) req.send_request() end |
#create_cluster(params = {}) ⇒ Types::CreateClusterOutput
Creates a new Amazon DocumentDB elastic cluster and returns its cluster structure.
795 796 797 798 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 795 def create_cluster(params = {}, = {}) req = build_request(:create_cluster, params) req.send_request() end |
#create_cluster_snapshot(params = {}) ⇒ Types::CreateClusterSnapshotOutput
Creates a snapshot of an elastic cluster.
846 847 848 849 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 846 def create_cluster_snapshot(params = {}, = {}) req = build_request(:create_cluster_snapshot, params) req.send_request() end |
#delete_cluster(params = {}) ⇒ Types::DeleteClusterOutput
Delete an elastic cluster.
895 896 897 898 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 895 def delete_cluster(params = {}, = {}) req = build_request(:delete_cluster, params) req.send_request() end |
#delete_cluster_snapshot(params = {}) ⇒ Types::DeleteClusterSnapshotOutput
Delete an elastic cluster snapshot.
936 937 938 939 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 936 def delete_cluster_snapshot(params = {}, = {}) req = build_request(:delete_cluster_snapshot, params) req.send_request() end |
#get_cluster(params = {}) ⇒ Types::GetClusterOutput
Returns information about a specific elastic cluster.
985 986 987 988 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 985 def get_cluster(params = {}, = {}) req = build_request(:get_cluster, params) req.send_request() end |
#get_cluster_snapshot(params = {}) ⇒ Types::GetClusterSnapshotOutput
Returns information about a specific elastic cluster snapshot
1025 1026 1027 1028 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1025 def get_cluster_snapshot(params = {}, = {}) req = build_request(:get_cluster_snapshot, params) req.send_request() end |
#get_pending_maintenance_action(params = {}) ⇒ Types::GetPendingMaintenanceActionOutput
Retrieves all maintenance actions that are pending.
1061 1062 1063 1064 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1061 def get_pending_maintenance_action(params = {}, = {}) req = build_request(:get_pending_maintenance_action, params) req.send_request() end |
#list_cluster_snapshots(params = {}) ⇒ Types::ListClusterSnapshotsOutput
Returns information about snapshots for a specified elastic cluster.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1123 1124 1125 1126 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1123 def list_cluster_snapshots(params = {}, = {}) req = build_request(:list_cluster_snapshots, params) req.send_request() end |
#list_clusters(params = {}) ⇒ Types::ListClustersOutput
Returns information about provisioned Amazon DocumentDB elastic clusters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1169 1170 1171 1172 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1169 def list_clusters(params = {}, = {}) req = build_request(:list_clusters, params) req.send_request() end |
#list_pending_maintenance_actions(params = {}) ⇒ Types::ListPendingMaintenanceActionsOutput
Retrieves a list of all maintenance actions that are pending.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1218 1219 1220 1221 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1218 def list_pending_maintenance_actions(params = {}, = {}) req = build_request(:list_pending_maintenance_actions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags on a elastic cluster resource
1247 1248 1249 1250 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1247 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#restore_cluster_from_snapshot(params = {}) ⇒ Types::RestoreClusterFromSnapshotOutput
Restores an elastic cluster from a snapshot.
1342 1343 1344 1345 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1342 def restore_cluster_from_snapshot(params = {}, = {}) req = build_request(:restore_cluster_from_snapshot, params) req.send_request() end |
#start_cluster(params = {}) ⇒ Types::StartClusterOutput
Restarts the stopped elastic cluster that is specified by ‘clusterARN`.
1392 1393 1394 1395 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1392 def start_cluster(params = {}, = {}) req = build_request(:start_cluster, params) req.send_request() end |
#stop_cluster(params = {}) ⇒ Types::StopClusterOutput
Stops the running elastic cluster that is specified by ‘clusterArn`. The elastic cluster must be in the available state.
1442 1443 1444 1445 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1442 def stop_cluster(params = {}, = {}) req = build_request(:stop_cluster, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds metadata tags to an elastic cluster resource
1470 1471 1472 1473 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1470 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes metadata tags from an elastic cluster resource
1496 1497 1498 1499 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1496 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_cluster(params = {}) ⇒ Types::UpdateClusterOutput
Modifies an elastic cluster. This includes updating admin-username/password, upgrading the API version, and setting up a backup window and maintenance window
1618 1619 1620 1621 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1618 def update_cluster(params = {}, = {}) req = build_request(:update_cluster, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1647 1648 1649 |
# File 'lib/aws-sdk-docdbelastic/client.rb', line 1647 def waiter_names [] end |